# -*- coding: utf-8 -*-
from django import forms

from portailuser.fields import PortailUserField
from frappe.models import Annee, Filiere, Matiere, Tag, Document, Commentaire
from frappe.forms import DocumentFileField, CreateDocumentForm


class AnneeForm(forms.ModelForm):
    class Meta:
        model = Annee
        fields = ("nom",)


class FiliereForm(forms.ModelForm):
    class Meta:
        model = Filiere
        fields = ("nom", "annee")

    def __init__(self, *args, **kwargs):
        ecole = kwargs.pop("ecole")
        super(FiliereForm, self).__init__(*args, **kwargs)
        self.fields["annee"].queryset = Annee.objects.filter(ecole=ecole).order_by("nom")


class MatiereForm(forms.ModelForm):
    class Meta:
        model = Matiere
        fields = ("nom", "filiere")

    def __init__(self, *args, **kwargs):
        ecole = kwargs.pop("ecole")
        super(MatiereForm, self).__init__(*args, **kwargs)
        self.fields["filiere"].queryset = (
            Filiere.objects.filter(annee__ecole=ecole).select_related("annee").order_by("annee__nom", "nom")
        )


class TagForm(forms.ModelForm):
    class Meta:
        model = Tag
        fields = ("nom", "color")
        widgets = {
            "color": forms.TextInput(attrs={"type": "color"}),
        }


class EditDocumentForm(CreateDocumentForm):
    class Meta:
        model = Document
        fields = ("nom", "annee", "matiere", "fichier", "tags", "auteur", "description")
        bbcode_field = "description"

    fichier = DocumentFileField(widget=forms.FileInput(), required=False)
    auteur = PortailUserField()


class CommentaireForm(forms.ModelForm):
    class Meta:
        model = Commentaire
        fields = ("auteur", "message")

    auteur = PortailUserField()
